@@ -19,8 +19,6 @@ sub prepare_dot_cpan {
     unlink _f"t/dot-cpan/.lock";
     mkpath _d"t/dot-cpan/sources/authors/id/A/AN/ANDK";
     mkpath _d"t/dot-cpan/Bundle";
-    # cp is not-overwriting on OS/2
-    unlink _f"t/CPAN/MyConfig.pm", _f"t/dot-cpan/sources/MIRRORED.BY";
     cp _f"t/CPAN/TestConfig.pm", _f"t/CPAN/MyConfig.pm"
         or die "Could not cp t/CPAN/TestConfig.pm over t/CPAN/MyConfig.pm: $!";
     cp _f"t/CPAN/TestMirroredBy", _f"t/dot-cpan/sources/MIRRORED.BY"
@@ -29,7 +27,6 @@ sub prepare_dot_cpan {
 
 sub cleanup_dot_cpan {
     unlink _f"t/dot-cpan/sources/authors/id/A/AN/ANDK/CHECKSUMS";
-    unlink _f"t/dot-cpan/sources/MIRRORED.BY";
     unlink _f"t/dot-cpan/prefs/FTPstats.yml";
     unlink _f"t/dot-cpan/prefs/TestDistroPrefsFile.yml";
     unlink _f"t/dot-cpan/prefs/ANDK.CPAN-Test-Dummy-Perl5-Make-Expect.yml";
